#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const globby_1 = __importDefault(require("globby"));
const TestRunner_1 = require("./TestRunner");
const TestRunnerCli_1 = require("./cli/TestRunnerCli");
const readConfig_1 = require("./readConfig");
const dedupeArray = (arr) => [...new Set(arr)];
async function collectTestFiles(patterns) {
    const testFiles = [];
    for (const pattern of Array.isArray(patterns) ? patterns : [patterns]) {
        testFiles.push(...(await globby_1.default(pattern)));
    }
    return dedupeArray(testFiles).map((f) => f);
}
(async () => {
    const config = await readConfig_1.readConfig();
    const testFiles = await collectTestFiles(config.files);
    if (testFiles.length === 0) {
        console.error(`Could not find any files with pattern(s): ${config.files}`);
        process.exit(1);
    }
    const runner = new TestRunner_1.TestRunner(config, testFiles);
    const cli = new TestRunnerCli_1.TestRunnerCli(config, runner);
    function stop() {
        runner.stop();
    }
    ['exit', 'SIGINT'].forEach((event) => {
        process.on(event, stop);
    });
    process.on('uncaughtException', (error) => {
        /* eslint-disable-next-line no-console */
        console.error(error);
        stop();
    });
    await runner.start();
    await cli.start();
})();
//# sourceMappingURL=bin.js.map