"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventEmitter = exports.createTestSessions = exports.filtered = void 0;
const uuid_1 = require("uuid");
const events_1 = require("events");
const TestSessionStatus_1 = require("./TestSessionStatus");
function* filtered(it, filter) {
    while (true) {
        const { value, done } = it.next();
        if (done)
            return;
        if (filter(value))
            yield value;
    }
}
exports.filtered = filtered;
function createTestSessions(browserNames, testFiles) {
    const sessions = [];
    // when running each test files in a separate tab, we group tests by file
    for (const testFile of testFiles) {
        const group = testFile;
        const sessionsForFile = browserNames.map((browserName) => ({
            id: uuid_1.v4(),
            testRun: -1,
            group,
            browserName,
            status: TestSessionStatus_1.STATUS_SCHEDULED,
            testFile,
        }));
        for (const session of sessionsForFile) {
            sessions.push(session);
        }
    }
    return sessions;
}
exports.createTestSessions = createTestSessions;
class EventEmitter {
    constructor() {
        this.__emitter = new events_1.EventEmitter();
    }
    on(eventName, fn) {
        this.__emitter.on(eventName, fn);
    }
    off(eventName, fn) {
        this.__emitter.off(eventName, fn);
    }
    emit(eventName, params) {
        this.__emitter.emit(eventName, params);
    }
}
exports.EventEmitter = EventEmitter;
//# sourceMappingURL=utils.js.map