"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.playwrightLauncher = void 0;
const playwright_1 = __importDefault(require("playwright"));
const constants_1 = require("../../core/constants");
const validBrowserTypes = ['chromium', 'firefox', 'webkit'];
function playwrightLauncher({ browserTypes = ['chromium'], } = {}) {
    const browsers = new Map();
    const debugBrowsers = new Map();
    const activePages = new Map();
    const createUrl = (session) => `${serverAddress}?${constants_1.PARAM_SESSION_ID}=${session.id}`;
    const inactivePages = [];
    if (browserTypes.some((t) => !validBrowserTypes.includes(t))) {
        throw new Error(`Invalid browser types: ${browserTypes}. Valid browser types: ${validBrowserTypes.join(', ')}`);
    }
    let config;
    let serverAddress;
    return {
        async start(_config) {
            config = _config;
            serverAddress = `${config.address}:${config.port}/`;
            const browserNames = [];
            for (const type of browserTypes) {
                const name = `${type[0].toUpperCase()}${type.substring(1)}`;
                browserNames.push(name);
                const browser = await playwright_1.default[type].launch();
                browsers.set(name, browser);
            }
            return browserNames;
        },
        async stop() {
            for (const browser of browsers.values()) {
                await browser.close();
            }
            for (const browser of debugBrowsers.values()) {
                await browser.close();
            }
        },
        async startDebugSession(session) {
            const browserType = session.browserName.toLowerCase();
            if (!validBrowserTypes.includes(browserType)) {
                throw new Error(`Invalid browser type: ${browserType}`);
            }
            let browser = debugBrowsers.get(browserType);
            if (browser && browser.isConnected()) {
                await browser.close();
            }
            browser = await playwright_1.default[browserType].launch({ headless: false });
            debugBrowsers.set(browserType, browser);
            const page = await browser.newPage();
            await page.goto(`${createUrl(session)}&${constants_1.PARAM_DEBUG}=true`);
        },
        async startSession(session) {
            const browser = browsers.get(session.browserName);
            if (!browser) {
                throw new Error(`Unknown browser name: ${browser}`);
            }
            if (!browser.isConnected()) {
                throw new Error('Browser is closed');
            }
            let page;
            if (true && inactivePages.length === 0) {
                page = await browser.newPage();
            }
            else {
                page = inactivePages.pop();
            }
            activePages.set(session.id, page);
            await page.goto(createUrl(session));
        },
        stopSession(session) {
            const page = activePages.get(session.id);
            if (page) {
                activePages.delete(session.id);
                inactivePages.push(page);
            }
        },
    };
}
exports.playwrightLauncher = playwrightLauncher;
//# sourceMappingURL=playwright-launcher.js.map